@@ -25,9 +25,10 @@ THE SOFTWARE.
 
 
 from pudb.settings import load_config
+import sys
 
 
-NUM_VERSION = (2021, 2, 2)
+NUM_VERSION = (2022, 1, 1)
 VERSION = ".".join(str(nv) for nv in NUM_VERSION)
 __version__ = VERSION
 
@@ -35,7 +36,6 @@ __version__ = VERSION
 class PudbShortcuts:
     @property
     def db(self):
-        import sys
         dbg = _get_debugger()
 
         import threading
@@ -45,7 +45,6 @@ class PudbShortcuts:
 
     @property
     def go(self):
-        import sys
         dbg = _get_debugger()
 
         import threading
@@ -58,9 +57,6 @@ import builtins
 builtins.__dict__["pu"] = PudbShortcuts()
 
 
-CURRENT_DEBUGGER = []
-
-
 def _tty_override():
     import os
     return os.environ.get("PUDB_TTY")
@@ -76,7 +72,8 @@ def _open_tty(tty_path):
 
 
 def _get_debugger(**kwargs):
-    if not CURRENT_DEBUGGER:
+    from pudb.debugger import Debugger
+    if not Debugger._current_debugger:
         tty_path = _tty_override()
         if tty_path and ("stdin" not in kwargs or "stdout" not in kwargs):
             tty_file, term_size = _open_tty(tty_path)
@@ -87,14 +84,14 @@ def _get_debugger(**kwargs):
         from pudb.debugger import Debugger
         dbg = Debugger(**kwargs)
 
-        CURRENT_DEBUGGER.append(dbg)
         return dbg
     else:
-        return CURRENT_DEBUGGER[0]
+        return Debugger._current_debugger[0]
 
 
 def _have_debugger():
-    return len(CURRENT_DEBUGGER) > 0
+    from pudb.debugger import Debugger
+    return bool(Debugger._current_debugger)
 
 
 import signal  # noqa
@@ -117,7 +114,6 @@ def runscript(mainpyfile, args=None, pre_run="", steal_output=False,
     # have a "restart" command which would allow explicit specification of
     # command line arguments.
 
-    import sys
     if args is not None:
         prev_sys_argv = sys.argv[:]
         if run_as_module:
@@ -209,15 +205,15 @@ def runscript(mainpyfile, args=None, pre_run="", steal_output=False,
 
 
 def runstatement(statement, globals=None, locals=None):
-    _get_debugger().run(statement, globals, locals)
+    return _get_debugger().run(statement, globals, locals)
 
 
 def runeval(expression, globals=None, locals=None):
     return _get_debugger().runeval(expression, globals, locals)
 
 
-def runcall(*args, **kwds):
-    return _get_debugger().runcall(*args, **kwds)
+def runcall(*args, **kwargs):
+    return _get_debugger().runcall(*args, **kwargs)
 
 
 def set_trace(paused=True):
@@ -308,25 +304,19 @@ def post_mortem(tb=None, e_type=None, e_value=None):
     else:
         exc_info = (e_type, e_value, tb)
 
-    tb = exc_info[2]
-    while tb.tb_next is not None:
-        tb = tb.tb_next
-
     dbg = _get_debugger()
     dbg.reset()
-    dbg.interaction(tb.tb_frame, exc_info)
+    dbg.interaction(None, exc_info)
 
 
 def pm():
     import sys
-    try:
-        e_type = sys.last_type
-        e_value = sys.last_value
-        tb = sys.last_traceback
-    except AttributeError:
+    exc_type, exc_val, tb = sys.exc_info()
+
+    if exc_type is None:
         # No exception on record. Do nothing.
         return
-    post_mortem(tb, e_type, e_value)
+    post_mortem()
 
 
 if __name__ == "__main__":
