@@ -1,3 +1,11 @@
+"""
+.. autoclass:: RemoteDebugger
+
+.. autofunction:: set_trace
+.. autofunction:: debugger
+.. autofunction:: debug_remote_on_single_rank
+"""
+
 __copyright__ = """
 Copyright (C) 2009-2017 Andreas Kloeckner
 Copyright (C) 2014-2017 Aaron Meurer
@@ -36,10 +44,12 @@ import fcntl
 import termios
 import struct
 import atexit
+from typing import Callable, Any
 
 from pudb.debugger import Debugger
 
-__all__ = ["PUDB_RDB_HOST", "PUDB_RDB_PORT", "default_port", "debugger", "set_trace"]
+__all__ = ["PUDB_RDB_HOST", "PUDB_RDB_PORT", "default_port", "debugger", "set_trace",
+           "debug_remote_on_single_rank"]
 
 default_port = 6899
 
@@ -58,7 +68,8 @@ Please specify one using the PUDB_RDB_PORT environment variable.
 """
 
 BANNER = """\
-{self.ident}: Please telnet into {self.host} {self.port}.
+{self.ident}: Please start a telnet session using a command like:
+telnet {self.host} {self.port}
 {self.ident}: Waiting for client...
 """
 
@@ -77,6 +88,10 @@ Please specify one using the PUDB_RDB_PORT environment variable.
 
 
 class RemoteDebugger(Debugger):
+    """
+    .. automethod:: __init__
+    """
+
     me = "pudb"
     _prev_outs = None
     _sock = None
@@ -90,8 +105,24 @@ class RemoteDebugger(Debugger):
         term_size=None,
         reverse=False,
     ):
+        """
+        :arg term_size: A two-tuple ``(columns, rows)``, or *None*. If *None*,
+            try to determine the terminal size automatically.
+
+            Currently, this uses a heuristic: It uses the terminal size of the
+            debuggee as that for the debugger. The idea is that you might be
+            running both in two tabs of the same terminal window, hence using
+            terminals of the same size.
+        """
         self.out = out
 
+        if term_size is None:
+            try:
+                s = struct.unpack("hh", fcntl.ioctl(1, termios.TIOCGWINSZ, "1234"))
+                term_size = (s[1], s[0])
+            except Exception:
+                term_size = (80, 24)
+
         self._prev_handles = sys.stdin, sys.stdout
         self._client, (address, port) = self.get_client(
             host=host, port=port, search_limit=port_search_limit, reverse=reverse
@@ -205,14 +236,30 @@ def set_trace(
     """Set breakpoint at current location, or a specified frame"""
     if frame is None:
         frame = _frame().f_back
-    if term_size is None:
-        try:
-            # Getting terminal size
-            s = struct.unpack("hh", fcntl.ioctl(1, termios.TIOCGWINSZ, "1234"))
-            term_size = (s[1], s[0])
-        except Exception:
-            term_size = (80, 24)
 
     return debugger(
         term_size=term_size, host=host, port=port, reverse=reverse
     ).set_trace(frame)
+
+
+def debug_remote_on_single_rank(comm: Any, rank: int, func: Callable,
+                                *args: Any, **kwargs: Any) -> None:
+    """Run a remote debugger on a single rank of an ``mpi4py`` application.
+    *func* will be called on rank *rank* running in a :class:`RemoteDebugger`,
+    and will be called normally on all other ranks.
+
+    :param comm: an ``mpi4py`` ``Comm`` object.
+    :param rank: the rank to debug. All other ranks will spin until this rank exits.
+    :param func: the callable to debug.
+    :param args: the arguments passed to ``func``.
+    :param kwargs: the kwargs passed to ``func``.
+    """
+    if comm.rank == rank:
+        debugger().runcall(func, *args, **kwargs)
+    else:
+        try:
+            func(*args, **kwargs)
+        finally:
+            from time import sleep
+            while True:
+                sleep(1)
